
globals [
  capital                     ; capital stock
  economic_output             ; economic output of world economy
  economic_output_T1          ; economic output in previous year
  des_economic_growth         ; desired economic growth rate
  min_economic_growth         ; minimum requested economic growth rate
  d_economic_output           ; economic growth rate observed 
  d_economic_output_T1        ; observed economic growth rate in previous year
  Consumption                 ; world level consumption
  a                           ; technology parameter 
  Population                  ; Population projections
  Emissions                   ; Global emissions of CO2
  sigma                       ; energy intensity
  gamma                       ; elasticity of Cobb-Douglas production function
  alpha                       ; conversion parameter from economic output into CO2 emissions
  techgrowthrate              ; rate at which technology affecting economic output changes
  lossratetechgrowthrate      ; rate at which growth of technological progress slows down
  lcc                         ; contribution of available low-cost conservation measures
  depreciation_rate_capital   ; depreciation rate of capital stock
  frI                         ; Investment fraction of output into capital stock 
  frI-i                       ; Desired investment fraction of output into capital stock from individualist perspective
  frI-e                       ; Desired investment fraction of output into capital stock from egalitarian perspective
  frI-h                       ; Desired investment fraction of output into capital stock from hierarchist perspective
  frI-T1                      ; Investment fraction in previous year
  red_tape                    ; delay in adjusting capital investment fraction for the hierarchist perspective
  shareI                      ; Share of individualist's perspective in population
  shareE                      ; Share of egalitarian's perspective in population
  shareH                      ; Share of hierarchist's perspective in population
  pCO2                        ; CO2 concentration in atmosphere
  pCO20                       ; Pre-industrial CO2 concentration
  dQ2xCO2                     ; radiative forcing associated with a doubled CO2 concentration
  dQCO2                       ; change of radiative forming of CO2
  dTp                         ; potential change of temperature change
  dT                          ; actual temperature change
  dT2xCO2                     ; global mean surface temperature change in the event of a doubled CO2 concentration
  beta                        ; rate of delayed response between potential and actual temperature change
  rsigma                      ; number of years required to double energy efficiency
  rred                        ; number of years which would be required to reduce the share of fossil fuelds within the energy mix by 50 percent.
  rredt1                      ; rred in previous year
  rredE                       ; desired rred for egalitarian perspective
  rredH                       ; desired rred for hierarchist perspective
  rredI                       ; desired rred for individualist perspective
  rredchange                  ; desired rred weighted for different perspectives in population
  F                           ; One minus percentage of emission reductions
  b1                          ; scale of emission reduction cost function
  b2                          ; non-linearity of emission reduction costs
  delta1                      ; scale of damage cost function
  delta2                      ; non-lineary of damage cost function
  damagecost                  ; damage costs due to climate change
  damagecostT1                ; damage costs in previous year                     ; 
  class1                      ; first carbon stock
  class2                      ; second carbon stock
  class3                      ; third carbon stock
  class4                      ; fourth carbon stock
  class5                      ; fifth carbon stock
  starttime                   ; base year 1995
  measured-dY                 ; measured economic growth
  measured-T                  ; measured temperature change
  ET-E                        ; expected temperature change according to egalitarian perspective
  ET-H                        ; expected temperature change according to hierarchist perspective
  fitness-I                   ; fitness of individualist perspective
  fitness-E                   ; fitness of egalitarian perspective
  fitness-H                   ; fitness of hierarchist perspective
]

turtles-own [
  share-Ei                    ; share of egalitarian perspective
  share-Hi                    ; share of hierarchist perspective
  share-Ii                    ; share of individualist perspective
  newshare-Ei                 ; share of egalitarian perspective
  newshare-Hi                 ; share of hierarchist perspective
  newshare-Ii                 ; share of individualist perspective
  fitness                     ; fitness of perspective of agent
  ]

to setup
  clear-all
  set gamma 0.25
  set alpha 0.32
  set a 0.01325
  set red_tape 0.1
  set techgrowthrate 0.011518
  set starttime 1995  
  set capital 29.476
  set frI 0.21
  set frI-h 0.21
  set frI-e 0.21
  set frI-i 0.21 
  set frI-T1 0.21
  set depreciation_rate_capital 0.1
  set pCO2 365
  set pCO20 365
  set class1 365
  set class2 0
  set class3 0
  set class4 0
  set class5 0
  set dQ2xCO2 4.3
  set beta 0.05
  set rred 100
  set rredT1 100
  set rsigma 50
  set dTp 0
  set dT 0
  set damagecostT1 0
  set d_economic_output_T1 0.01
  set des_economic_growth 0.015
  set min_economic_growth 0.018
  set d_economic_output_T1 0.01
  set measured-dY 0.035
  set measured-T 0
  set fitness-I 0
  set fitness-E 0
  set fitness-H 0
  set lcc 0.5


  if World = "individualist" [set b1 0.25   set b2 3.5   set delta1 0       set delta2 0 set dT2xCO2 0.5 set lossratetechgrowthrate 0.004 set lcc 0.4]
  if World = "hierarchist"   [set b1 0.1108 set b2 2.887 set delta1 0.00144 set delta2 2 set dT2xCO2 2.5 set lossratetechgrowthrate 0.012 set lcc 0.5]
  if World = "egalitarian"   [set b1 0.05   set b2 2.3   set delta1 0.004   set delta2 4 set dT2xCO2 5.5 set lossratetechgrowthrate 0.024 set lcc 0.6]
  set Population (list 5749 5840.2 5931 6023 6114 6205 6293 6382 6470 6558 6647 6735 6824 6912 7000 7089 7177 7265 7354 7442 7530 7619 7707 7795 7884 7972 8061 8149 8237 8326 8414 8479 8543 8608 8673 8737 8802 8867 8931 8996 9061 9125 9190 9255 9320 9384 9449 9514 9578 9643 9708 9772 9837 9902 9966 10031 10057 10082 10108 10133 10159 10185 10210 10236 10262 10287 10313 10338 10364 10390 10415 10441 10467 10492 10518 10543 10569 10595 10620 10646 10672 10697 10723 10748 10774 10800 10825 10851 10876 10902 10928 10953 10979 11005 11030 11056 11081 11107 11133 11158 11184 11210 11235 11261 11286 11312)
  if World = "hierarchist" [set measured-T 0.5]
  if World = "egalitarian" [set measured-T 0.7]
  set ET-H measured-T
  set ET-E measured-T
  set economic_output a * (1 / (1 + delta1 * (dT ^ delta2))) * (capital ^ gamma) * (item 0 Population ^ (1 - gamma))
  set Emissions alpha * economic_output
  crt nragents [
    if Start = "Random" [
      let ax random-float 1
      let bx random-float 1
      let cx random-float 1
      set share-Ei ax / (ax + bx + cx)
      set share-Hi bx / (ax + bx + cx)
      set share-Ii cx / (ax + bx + cx)
    ]
    if Start = "Egalitarian" [
      set share-Ei 1
      set share-Hi 0
      set share-Ii 0
    ]
    if Start = "Individualist" [
      set share-Ei 0
      set share-Hi 0
      set share-Ii 1
    ]
    if Start = "Hierarchist" [
      set share-Ei 0
      set share-Hi 1
      set share-Ii 0
    ]
    set fitness 0
  ]
  set shareI mean [share-Ii] of turtles
  set shareE mean [share-Ei] of turtles
  set shareH mean [share-Hi] of turtles
  reset-ticks
  while [ticks < 1995][tick]
end


to go
  tick
  model
  beliefchange
  if ticks = 2101 [stop]
end

to model 
  ifelse economic_output_T1 != 0 [set d_economic_output (economic_output - economic_output_T1) / economic_output_T1][set d_economic_output 0]
  
  ; Define capital investments for different perspectives
    
  if ticks > (starttime + 1) [
    if d_economic_output_T1 != 0 [
    set frI-h frI-T1 * ( 1 - red_tape) + red_tape * des_economic_growth * ( frI-T1 / d_economic_output_T1)] 
    if frI-h > 1 [set frI-h 1]
    if frI-h < 0 [set frI-h 0]
  ]

  if ticks > starttime [
    ifelse d_economic_output <= 0 or d_economic_output_T1 <= 0[set frI-i frI-T1]
    [
      ifelse d_economic_output < min_economic_growth [
       set frI-i min_economic_growth * frI-T1 / d_economic_output_T1
       if frI-i > 1 [set frI-i 1]
       if frI-i < 0 [set frI-i 0]
     ][set frI-i frI-T1]
  ]
  ]
  set frI-e depreciation_rate_capital * capital / economic_output
  
  set frI-h frI + (frI-h - frI) * 0.2
  set frI-e frI + (frI-e - frI) * 0.2
  set frI-i frI + (frI-i - frI) * 0.2
  
  set frI shareH * frI-h + shareE * frI-e + shareI * frI-i
  
  ; Defining economic output
   
  set capital capital + frI * economic_output - depreciation_rate_capital * capital
  set Consumption (1 - frI) * economic_output
  set techgrowthrate 0.011518 * (exp (0 - lossratetechgrowthrate * (ticks - starttime)))
  set a a + a * techgrowthrate
  set economic_output_T1 economic_output
  
  ; Define investments in alternative fuel economy
 
  ifelse ticks > starttime [
    ifelse (dT >= 1.5) [set rredH 20 + (rredT1 - 20) * 0.98]
    [
     ifelse (dT >= 0.5 and dT < 1) [set rredH 20 + (rredT1 - 20) * 0.995]
     [
       ifelse (dT >= 1 and dT < 1.5) [set rredH 20 + (rredT1 - 20) * 0.99][set rredH 100]
     ]
    ]
  ][set rredH 100]

      
  ifelse dT > 0 [set damagecost delta1 * (dT ^ delta2)][set damagecost delta1 * (( 0 - dT) ^ delta2)]
  
  set rredE 20
  ifelse damagecostT1 > 0.01 [set rredI 20 + (rred - 20) * 0.99][set rredI 1000]
  set rredT1 rred
 
 ; Defining emissions
 

  set rredchange shareE * rredE + shareH * rredH + shareI * rredI
  set rred rred + (rredchange - rred) * 0.2
  
  set sigma (1 - lcc) + ( 1 / 0.99 ) * lcc / ( 1 + EXP( - ( 1 / rsigma) * LN(0.01 / 0.99) * (ticks - starttime - rsigma)))
  set F ( 1 / 0.99 ) * ( 1 / ( 1 + EXP( - ( 1 / rred) * LN(0.01 / 0.99) * ( (rred / rredT1) * (ticks - starttime) - rred))))
  
  
  set economic_output a * ((1 - (b1 * (1 - F) ^ b2)) / (1 + damagecost)) * (capital ^ gamma) * (item (ticks - starttime) Population ^ (1 - gamma))
  set Emissions alpha * F * sigma * economic_output
  
  ; Defining temperature change
  
  set class1 class1 + 0.131 * 0.471 * Emissions
  set class2 class2 + 0.471 * Emissions * (0.201 * exp ((ticks - starttime) / 362.9))
  set class3 class3 + 0.471 * Emissions * (0.321 * exp ((ticks - starttime) / 73.6))
  set class4 class4 + 0.471 * Emissions * (0.249 * exp ((ticks - starttime) / 17.3))
  set class5 class5 + 0.471 * Emissions * (0.098 * exp ((ticks - starttime) / 1.9))
  set pCO2 class1 +  class2 * exp (0 - (ticks - starttime) / 362.9) + class3 * exp (0 - (ticks - starttime) / 73.6) + class4 * exp (0 - (ticks - starttime) / 17.3) + class5 * exp (0 - (ticks - starttime) / 1.9)
  set dQCO2 dQ2xCO2 / (ln 2) * ln (pCO2 / 296)
  set dTp (dT2xCO2 / dQ2xCO2) * dQCO2
  set dT dT + beta * (dTp - dT)

  set damagecostT1 damagecost

  set frI-T1 frI
  
  set d_economic_output_T1 d_economic_output
end

to beliefchange
  ; Define fitness of perspectives
  let fitness-Hdy 0
  let fitness-Ht 0
  let measurehor 5

  set measured-dY measured-dY + (d_economic_output - measured-dY) / measurehor
  
  set measured-T measured-T + (dT - measured-T)/ measurehor
  set ET-H 2.5 / LN(2) * LN(pCO2 / 296) * 0.05 + 0.95 * ET-H
  set ET-E 5.5 / LN(2) * LN(pCO2 / 296) * 0.05 + 0.95 * ET-E
  
  ifelse abs (0.02 - measured-dY) <= tolY [set fitness-I 1]
  [ifelse 0.02 > (measured-dY + tolY) [set fitness-I 1 - (0.02 - measured-dY - tolY)/(0.005 + 0.02 - measured-dY - tolY)][set fitness-I 1]] ; if the economy grows faster than expected, ignore it
  
  ifelse abs (0.015 - measured-dY) <= tolY [set fitness-Hdy 1]
  [ifelse 0.015 > (measured-dY + tolY) [set fitness-Hdy 1 - (0.015 - measured-dY - tolY)/(0.005 + 0.015 - measured-dY - tolY)][set fitness-Hdy 1 - (measured-dY - tolY - 0.015)/(0.005 - tolY + measured-dY - 0.015) ]]

  ifelse abs (ET-H - measured-T) <= tolT [set fitness-Ht 1]
  [ifelse ET-H > (measured-T + tolT) [set fitness-Ht 1 - (ET-H - measured-T - tolT)/(0.5 + ET-H - measured-T - tolT)][set fitness-Ht 1 - (measured-T - ET-H - tolT)/(0.5 + measured-T - ET-H - tolT)]]

  set fitness-H (fitness-Hdy + fitness-Ht)/ 2

  ifelse abs (ET-E - measured-T) <= tolT [set fitness-E 1]
  [ifelse ET-E > (measured-T + tolT) [set fitness-E 1 - (ET-E - measured-T - tolT)/(0.5 + ET-E - measured-T - tolT)][set fitness-E 1 - (measured-T - ET-E - tolT)/(0.5 + measured-T - ET-E - tolT)]]
  
  let sumfitness 0
  ask turtles [
   set fitness share-Ii * fitness-I + share-Hi * fitness-H + share-Ei * fitness-E
   set sumfitness sumfitness + fitness
  ] 
  
  ; Draw next generation of perspectives based on relative fitness
  ask turtles [
     let random-draw random-float sumfitness
     let cumfitness 0
     let i 0
     while [i < nragents]
     [
       ifelse cumfitness + [fitness] of turtle i > random-draw [
         set newshare-Ii [share-Ii] of turtle i
         set newshare-Ei [share-Ei] of turtle i
         set newshare-Hi [share-Hi] of turtle i
         set i nragents
       ][
       set cumfitness cumfitness + [fitness] of turtle i
       set i i + 1]
     ]
  ]
  
  ask turtles [
    set newshare-Ii newshare-Ii + random-normal 0 stdev
    set newshare-Ei newshare-Ei + random-normal 0 stdev
    set newshare-Hi newshare-Hi + random-normal 0 stdev
    if newshare-Ii < 0 [set newshare-Ii 0]
    if newshare-Ii > 1 [set newshare-Ii 1]
    if newshare-Ei < 0 [set newshare-Ei 0]
    if newshare-Ei > 1 [set newshare-Ei 1]
    if newshare-Hi < 0 [set newshare-Hi 0]
    if newshare-Hi > 1 [set newshare-Hi 1]
    
    set share-Ii newshare-Ii / (newshare-Ii + newshare-Ei + newshare-Hi)
    set share-Ei newshare-Ei / (newshare-Ii + newshare-Ei + newshare-Hi)
    set share-Hi newshare-Hi / (newshare-Ii + newshare-Ei + newshare-Hi)
  ]
  
  set shareI mean [share-Ii] of turtles
  set shareE mean [share-Ei] of turtles
  set shareH mean [share-Hi] of turtles
end
@#$#@#$#@
GRAPHICS-WINDOW
27
321
272
506
16
16
4.67
1
10
1
1
1
0
1
1
1
-16
16
-16
16
0
0
1
ticks
3.0

BUTTON
15
19
78
52
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
87
19
150
52
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
163
10
546
248
World Economic Product
Year
Billions dollars
1995.0
2100.0
0.0
200.0
false
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot economic_output"

CHOOSER
17
75
155
120
World
World
"egalitarian" "hierarchist" "individualist"
0

PLOT
549
10
918
251
Temperate change
Year
Degrees Celsius
1995.0
2100.0
0.0
6.0
false
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot dT"

PLOT
549
250
919
493
CO2 concentration
Year
ppmv
1995.0
2100.0
0.0
1000.0
false
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot pCO2"

PLOT
163
250
546
493
Emissions
Year
GtC
1995.0
2100.0
0.0
50.0
false
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot Emissions"

PLOT
921
253
1321
494
fitness
NIL
NIL
1995.0
2100.0
0.0
1.0
false
true
"" ""
PENS
"I" 1.0 0 -16777216 true "" "plot fitness-I"
"H" 1.0 0 -13345367 true "" "plot fitness-H"
"E" 1.0 0 -2674135 true "" "plot fitness-E"

SLIDER
18
124
158
157
tolY
tolY
0
0.02
0.02
0.001
1
NIL
HORIZONTAL

SLIDER
19
157
156
190
tolT
tolT
0
2
2
0.1
1
NIL
HORIZONTAL

SLIDER
18
279
156
312
nragents
nragents
0
100
100
1
1
NIL
HORIZONTAL

SLIDER
15
197
157
230
stdev
stdev
0
0.1
0.02
0.01
1
NIL
HORIZONTAL

PLOT
920
10
1319
252
perspectives
NIL
NIL
1995.0
2100.0
0.0
1.0
false
true
"" ""
PENS
"I" 1.0 0 -16777216 true "" "plot shareI"
"H" 1.0 0 -13791810 true "" "plot shareH"
"E" 1.0 0 -2674135 true "" "plot shareE"

CHOOSER
18
232
156
277
Start
Start
"random" "Egalitarian" "Individualist" "Hierarchist"
2

@#$#@#$#@
This is a Netlogo implementation of the model described in Janssen, M.A. and H.J.M. de Vries (1998) The battle of perspectives: a multi-agent model with adaptive responses to climate change, Ecological Economics 26(1): 43-65; also found in the PhD dissertation of Marco A. Janssen of 1996.

The original model was implemented in 1995 in M, a language only used within the Dutch National Institute for Public Health and the Environment. 

The results of Janssen and de Vries (1998) are replicated with this Netlogo version.

The replication is performed by Marco A. Janssen, Arizona State University, November 2013.
 
Copyright (C) 1995 M.A. Janssen

This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.  
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.  
You should have received a copy of the GNU General Public License along with this program. If not, see <http://www.gnu.org/licenses/>.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0.3
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="105"/>
    <metric>economic_output</metric>
    <metric>Emissions</metric>
    <metric>dT</metric>
    <metric>shareI</metric>
    <metric>shareH</metric>
    <metric>shareE</metric>
    <enumeratedValueSet variable="World">
      <value value="&quot;egalitarian&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="Start">
      <value value="&quot;Individualist&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="tolY" first="0" step="0.0020" last="0.02"/>
    <enumeratedValueSet variable="nragents">
      <value value="100"/>
    </enumeratedValueSet>
    <steppedValueSet variable="tolT" first="0" step="0.2" last="2"/>
    <enumeratedValueSet variable="stdev">
      <value value="0.02"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 1.0 0.0
0.0 1 1.0 0.0
0.2 0 1.0 0.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
